@@ -4,12 +4,9 @@ import threading
 from typing import Callable, Sequence
 from urllib.parse import parse_qs, urlsplit
 
-from .. import http
-from .. import exceptions
-from ..api.async_api import AsyncBucket
-
-from ..compat import to_string
+from ..http import Headers, USER_AGENT
 from ..crypto import BaseCryptoProvider
+from ..api.async_api import AsyncBucket
 from ..models import AsyncGetObjectResult
 from ..headers import OSS_ENCRYPTION_CLIENT
 from ..api._utils import _make_range_string
@@ -91,9 +88,9 @@ class AsyncCryptoBucket(AsyncBucket):
         self.upload_contexts_lock = threading.Lock()
 
         if self.app_name:
-            self.user_agent = http.USER_AGENT + "/" + self.app_name + "/" + OSS_ENCRYPTION_CLIENT
+            self.user_agent = USER_AGENT + "/" + self.app_name + "/" + OSS_ENCRYPTION_CLIENT
         else:
-            self.user_agent = http.USER_AGENT + "/" + OSS_ENCRYPTION_CLIENT
+            self.user_agent = USER_AGENT + "/" + OSS_ENCRYPTION_CLIENT
 
     def _init_user_agent(self, headers):
         if "User-Agent" not in headers:
@@ -126,10 +123,10 @@ class AsyncCryptoBucket(AsyncBucket):
         """
         logger.debug("Start to put object to AsyncCryptoBucket")
 
-        headers = http.Headers(headers)
+        headers = Headers(headers)
         self._init_user_agent(headers)
         content_crypto_material = self.crypto_provider.create_content_material()
-        data = self.crypto_provider.make_encrypt_adapter(data, content_crypto_material.cipher)
+        data = self.crypto_provider.make_encrypt_adapter_async(data, content_crypto_material.cipher)
         headers = content_crypto_material.to_object_meta(headers)
 
         return await super(AsyncCryptoBucket, self).put_object(key, data, headers, progress_callback)
@@ -194,7 +191,7 @@ class AsyncCryptoBucket(AsyncBucket):
         if process:
             raise ClientError("Process object operation is not support for Crypto Bucket")
 
-        headers = http.Headers(headers)
+        headers = Headers(headers)
         self._init_user_agent(headers)
 
         discard = 0
@@ -220,7 +217,7 @@ class AsyncCryptoBucket(AsyncBucket):
 
         logger.debug(
             "Start to get object from AsyncCryptoBucket: {0}, key: {1}, range: {2}, headers: {3}, params: {4}".format(
-                self.bucket_name, to_string(key), range_string, headers, params
+                self.bucket_name, key, range_string, headers, params
             )
         )
         resp = await self._do("GET", self.bucket_name, key, headers=headers, params=params)
@@ -255,7 +252,7 @@ class AsyncCryptoBucket(AsyncBucket):
         if query and (AsyncBucket.PROCESS in query):
             raise ClientError("Process object operation is not support for Crypto Bucket")
 
-        headers = http.Headers(headers)
+        headers = Headers(headers)
         self._init_user_agent(headers)
 
         discard = 0
@@ -316,7 +313,7 @@ class AsyncCryptoBucket(AsyncBucket):
         返回值中的 `crypto_multipart_context` 记录了加密Meta信息，在upload_part时需要一并传入
         """
 
-        headers = http.Headers(headers)
+        headers = Headers(headers)
         self._init_user_agent(headers)
         if not upload_context or not upload_context.data_size:
             raise ClientError("It is not support none upload_context and must specify data_size of upload_context ")
@@ -373,7 +370,7 @@ class AsyncCryptoBucket(AsyncBucket):
                 upload_id, part_number
             )
         )
-        headers = http.Headers(headers)
+        headers = Headers(headers)
         self._init_user_agent(headers)
         if upload_context:
             context = upload_context
@@ -401,7 +398,7 @@ class AsyncCryptoBucket(AsyncBucket):
 
         cipher = copy.copy(content_crypto_material.cipher)
         cipher.initialize(plain_key, plain_iv, counter)
-        data = self.crypto_provider.make_encrypt_adapter(data, cipher)
+        data = self.crypto_provider.make_encrypt_adapter_async(data, cipher)
         resp = await super(AsyncCryptoBucket, self).upload_part(
             key, upload_id, part_number, data, progress_callback, headers
         )
@@ -425,12 +422,9 @@ class AsyncCryptoBucket(AsyncBucket):
         """
         logger.info("Start to complete multipart upload of AsyncCryptoBucket, upload_id = {0}".format(upload_id))
 
-        headers = http.Headers(headers)
+        headers = Headers(headers)
         self._init_user_agent(headers)
-        try:
-            resp = await super(AsyncCryptoBucket, self).complete_multipart_upload(key, upload_id, parts, headers)
-        except exceptions as e:
-            raise e
+        resp = await super(AsyncCryptoBucket, self).complete_multipart_upload(key, upload_id, parts, headers)
 
         return resp
 
@@ -445,12 +439,9 @@ class AsyncCryptoBucket(AsyncBucket):
         """
         logger.info("Start to abort multipart upload of AsyncCryptoBucket, upload_id = {0}".format(upload_id))
 
-        headers = http.Headers(headers)
+        headers = Headers(headers)
         self._init_user_agent(headers)
-        try:
-            resp = await super(AsyncCryptoBucket, self).abort_multipart_upload(key, upload_id)
-        except exceptions as e:
-            raise e
+        resp = await super(AsyncCryptoBucket, self).abort_multipart_upload(key, upload_id)
 
         return resp
 
