@@ -4,12 +4,9 @@ import threading
 from typing import Callable
 from urllib.parse import parse_qs, urlsplit
 
-from .. import http
-from .. import exceptions
-from .. import Bucket
-
-from ..compat import to_string
+from ..api import Bucket
 from ..models import GetObjectResult
+from ..http import Headers, USER_AGENT
 from ..crypto import BaseCryptoProvider
 from ..headers import OSS_ENCRYPTION_CLIENT
 from ..api._utils import _make_range_string
@@ -91,9 +88,9 @@ class CryptoBucket(Bucket):
         self.upload_contexts_lock = threading.Lock()
 
         if self.app_name:
-            self.user_agent = http.USER_AGENT + "/" + self.app_name + "/" + OSS_ENCRYPTION_CLIENT
+            self.user_agent = USER_AGENT + "/" + self.app_name + "/" + OSS_ENCRYPTION_CLIENT
         else:
-            self.user_agent = http.USER_AGENT + "/" + OSS_ENCRYPTION_CLIENT
+            self.user_agent = USER_AGENT + "/" + OSS_ENCRYPTION_CLIENT
 
     def _init_user_agent(self, headers):
         if "User-Agent" not in headers:
@@ -124,7 +121,7 @@ class CryptoBucket(Bucket):
         """
         logger.debug("Start to put object to CryptoBucket")
 
-        headers = http.Headers(headers)
+        headers = Headers(headers)
         self._init_user_agent(headers)
         content_crypto_material = self.crypto_provider.create_content_material()
         data = self.crypto_provider.make_encrypt_adapter(data, content_crypto_material.cipher)
@@ -158,7 +155,7 @@ class CryptoBucket(Bucket):
 
     def get_object(
         self,
-        key,
+        key: str,
         byte_range=None,
         headers=None,
         progress_callback: Callable[[int, int | None], None] | None = None,
@@ -192,7 +189,7 @@ class CryptoBucket(Bucket):
         if process:
             raise ClientError("Process object operation is not support for Crypto Bucket")
 
-        headers = http.Headers(headers)
+        headers = Headers(headers)
         self._init_user_agent(headers)
 
         discard = 0
@@ -218,7 +215,7 @@ class CryptoBucket(Bucket):
 
         logger.debug(
             "Start to get object from CryptoBucket: {0}, key: {1}, range: {2}, headers: {3}, params: {4}".format(
-                self.bucket_name, to_string(key), range_string, headers, params
+                self.bucket_name, key, range_string, headers, params
             )
         )
         resp = self._do("GET", self.bucket_name, key, headers=headers, params=params)
@@ -253,7 +250,7 @@ class CryptoBucket(Bucket):
         if query and (Bucket.PROCESS in query):
             raise ClientError("Process object operation is not support for Crypto Bucket")
 
-        headers = http.Headers(headers)
+        headers = Headers(headers)
         self._init_user_agent(headers)
 
         discard = 0
@@ -314,7 +311,7 @@ class CryptoBucket(Bucket):
         返回值中的 `crypto_multipart_context` 记录了加密Meta信息，在upload_part时需要一并传入
         """
 
-        headers = http.Headers(headers)
+        headers = Headers(headers)
         self._init_user_agent(headers)
         if not upload_context or not upload_context.data_size:
             raise ClientError("It is not support none upload_context and must specify data_size of upload_context ")
@@ -371,7 +368,7 @@ class CryptoBucket(Bucket):
                 upload_id, part_number
             )
         )
-        headers = http.Headers(headers)
+        headers = Headers(headers)
         self._init_user_agent(headers)
         if upload_context:
             context = upload_context
@@ -421,12 +418,9 @@ class CryptoBucket(Bucket):
         """
         logger.info("Start to complete multipart upload of CryptoBucket, upload_id = {0}".format(upload_id))
 
-        headers = http.Headers(headers)
+        headers = Headers(headers)
         self._init_user_agent(headers)
-        try:
-            resp = super(CryptoBucket, self).complete_multipart_upload(key, upload_id, parts, headers)
-        except exceptions as e:
-            raise e
+        resp = super(CryptoBucket, self).complete_multipart_upload(key, upload_id, parts, headers)
 
         return resp
 
@@ -441,12 +435,9 @@ class CryptoBucket(Bucket):
         """
         logger.info("Start to abort multipart upload of CryptoBucket, upload_id = {0}".format(upload_id))
 
-        headers = http.Headers(headers)
+        headers = Headers(headers)
         self._init_user_agent(headers)
-        try:
-            resp = super(CryptoBucket, self).abort_multipart_upload(key, upload_id)
-        except exceptions as e:
-            raise e
+        resp = super(CryptoBucket, self).abort_multipart_upload(key, upload_id)
 
         return resp
 
