@@ -1,9 +1,11 @@
 import logging
-import platform
+from typing import TYPE_CHECKING, BinaryIO
 
 import httpx
 from httpx import Headers
-from httpx._types import ProxiesTypes
+
+if TYPE_CHECKING:
+    from httpx._types import ProxyTypes
 
 from ..compat import to_bytes
 from ..__version__ import __version__
@@ -12,7 +14,7 @@ from ..types import OSSResponse, AsyncOSSResponse
 from ..utils import file_object_remaining_bytes, SizedFileAdapter
 
 
-USER_AGENT = f"aliyun-sdk-python-light/{__version__}({platform.system()}/{platform.release()}/{platform.machine()};{platform.python_version()})"
+USER_AGENT = f"aliyun-oss-x/{__version__}"
 
 logger = logging.getLogger(__name__)
 
@@ -20,10 +22,10 @@ logger = logging.getLogger(__name__)
 class Session:
     """属于同一个 Session 的请求共享一组连接池，如有可能也会重用HTTP连接。"""
 
-    def __init__(self, proxies: ProxiesTypes | None = None, http2: bool = True):
+    def __init__(self, proxies: "ProxyTypes | None" = None, http2: bool = True):
         self.proxies = proxies
         self.http2 = http2
-        self.client = httpx.Client(http2=http2, proxies=proxies)
+        self.client = httpx.Client(http2=http2, proxy=proxies)
 
     def do_request(self, req: "Request", timeout: float):
         try:
@@ -32,12 +34,12 @@ class Session:
             )
 
             if req.proxies:
-                self.client = httpx.Client(http2=self.http2, proxies=req.proxies)
+                self.client = httpx.Client(http2=self.http2, proxy=req.proxies)
 
             response = self.client.request(
                 method=req.method,
                 url=req.url,
-                content=req.data,
+                content=req.data,  # type: ignore
                 params=req.params,
                 headers=req.headers,
                 timeout=timeout,
@@ -52,11 +54,11 @@ class Request:
         self,
         method: str,
         url: str,
-        data=None,
+        data: "bytes | str | BinaryIO | None" = None,
         params: dict | None = None,
-        headers: dict | Headers | None = None,
+        headers: "dict | Headers | None" = None,
         app_name: str = "",
-        proxies: ProxiesTypes | None = None,
+        proxies: "ProxyTypes | None" = None,
         region: str | None = None,
         product: str | None = None,
         cloudbox_id: str | None = None,
@@ -90,10 +92,10 @@ class Request:
 class AsyncSession:
     """属于同一个异步 Session 的请求共享一组连接池,如有可能也会重用HTTP连接。"""
 
-    def __init__(self, proxies: ProxiesTypes | None = None, http2: bool = True):
-        self.default_proxies = proxies
+    def __init__(self, proxy: "ProxyTypes | None" = None, http2: bool = True):
+        self.default_proxy = proxy
         self.http2 = http2
-        self.client = httpx.AsyncClient(http2=http2, proxies=proxies)
+        self.client = httpx.AsyncClient(http2=http2, proxy=proxy)
 
     async def do_request(self, req: "AsyncRequest", timeout: float):
         try:
@@ -101,12 +103,12 @@ class AsyncSession:
                 f"发送异步请求,方法: {req.method}, URL: {req.url}, 参数: {req.params}, 头部: {req.headers}, 超时: {timeout}, 代理: {req.proxies}"
             )
 
-            if req.proxies and req.proxies != self.default_proxies:
-                async with httpx.AsyncClient(http2=self.http2, proxies=req.proxies) as client:
+            if req.proxies and req.proxies != self.default_proxy:
+                async with httpx.AsyncClient(http2=self.http2, proxy=req.proxies) as client:
                     response = await client.request(
                         method=req.method,
                         url=req.url,
-                        content=req.data,
+                        content=req.data,  # type: ignore
                         params=req.params,
                         headers=req.headers,
                         timeout=timeout,
@@ -115,7 +117,7 @@ class AsyncSession:
                 response = await self.client.request(
                     method=req.method,
                     url=req.url,
-                    content=req.data,
+                    content=req.data,  # type: ignore
                     params=req.params,
                     headers=req.headers,
                     timeout=timeout,
@@ -139,9 +141,9 @@ class AsyncRequest:
         url: str,
         data=None,
         params: dict | None = None,
-        headers: dict | Headers | None = None,
+        headers: "dict | Headers | None" = None,
         app_name: str = "",
-        proxies: ProxiesTypes | None = None,
+        proxies: "ProxyTypes | None" = None,
         region: str | None = None,
         product: str | None = None,
         cloudbox_id: str | None = None,
