@@ -1,7 +1,7 @@
-import os.path
 import logging
 from typing import Callable, Union, AsyncIterable, Iterable, AsyncIterator, Awaitable
 
+from ..crc import Crc64
 from ...compat import to_bytes
 from ...exceptions import ClientError
 from ...types import (
@@ -12,7 +12,6 @@ from ...types import (
     is_readable_buffer_sync,
     has_crc_attr,
 )
-from .. import Crc64
 
 
 logger = logging.getLogger(__name__)
@@ -54,9 +53,9 @@ class AsyncSizedFileAdapter:
 def file_object_remaining_bytes(fileobj):
     current = fileobj.tell()
 
-    fileobj.seek(0, os.SEEK_END)
+    fileobj.seek(0, 2)
     end = fileobj.tell()
-    fileobj.seek(current, os.SEEK_SET)
+    fileobj.seek(current, 0)
 
     return end - current
 
